define([
  'underscore',
  './templates.js',
  './steps/users.js',
  './steps/pipelines.js',
  './steps/custom.js',
  'text!./templates/tutorial.md',
  'css!./styles.css'
], function (_, createTemplatesRenderer, usersStep, pipelinesStep, customStep, tutorial) {
  'use strict';

  return function () {
    var self = this;

    // создаем инстанс 
    createTemplatesRenderer(this);
  
    this.callbacks = {
      init: function () {
        return true;
      },
      render: function () {
        return true;
      },
      bind_actions: function () {
        return true;
      },
      onSave: function () {
        return true;
      },

      register_steps: function () {
        // обязательно должен возврвщать
        // массив с элементами, структура
        // которых должна соответствовать
        // данному примеру
        return [
          // на этом шаге реализован пример
          // кастомной валидации полей
          {
            header: self.i18n('users').header,    // header является необязательным параметром,
                                                  // если нужен кастомный html для заголовка
                                                  // просто можно не передавать его сюда

            caption: self.i18n('users').caption,  // следующие два параметра можно не передавать тоже,
                                                  // тогда в правой панели не будет текстов
            description: self.i18n('users').description,

            handler: _.bind(usersStep, self) // функция, которая выполнится при запуске шага
          },

          // на этом шаге реализован пример
          // кастомного хранения данных
          {
            header: self.i18n('pipelines').header,
            caption: self.i18n('pipelines').caption,
            description: self.i18n('pipelines').description,
            handler: _.bind(pipelinesStep, self)
          },

          // на этом шаге реализован пример
          // использования нативных контролов amoCRM
          {
            caption: self.i18n('custom').caption,
            description: self.i18n('custom').description,
            handler: _.bind(customStep, self)
          },
        ];
      },

      finish_wizard: function (all_steps_data) {
        // выполнится после финиша мастера, когда пользователь
        // дошел до финального шага и закончил его
        // здесь можно отправить данные на свои эндпоинты
        // для создания всех необходимых сущностей в аккаунте
        //
        // ОБЯЗАТЕЛЬНО должна возвращать объект promise!
        return new Promise(function (resolve, reject) {
          alert(JSON.stringify(all_steps_data));

          resolve({ skip_tour: true });
        });
      },

      // после прохождения мастера и отработки финального
      // колбэка `finish_wizard`, запускается данный метод
      // для отображения туториала готового решения,
      // который должен вернуть Markdown-строку
      get_tutorial: function () {
        return tutorial;
      },
    };

    return this;
  };
});