define(['jquery', '../templates.js'], function ($, getTemplateRenderer) {
  'use strict';

  var getTemplate = getTemplateRenderer();

  function validateInput ($input) {
    var value = $input.val();

    if (!value) {
      return false;
    }

    if (!/.*@.*/.test(value)) {
      return false;
    }
    
    return true;
  }

  function validateForm ($form) {
    var errors_count = 0;

    $form.find(':input[type="text"]')
      .removeClass('crm-template-widget__input_error');

    $form.find('.crm-template-widget__block').each(function () {
      var valid_inputs = 0;

      $(this).find(':input[type="text"]').each(function () {
        var is_valid = validateInput($(this));

        if (!is_valid) {
          $(this).addClass('crm-template-widget__input_error');
        }

        valid_inputs += is_valid ? 1 : 0;
      });

      if (valid_inputs === 0) {
        errors_count++;
      } else {
        $(this).find(':input[type="text"]')
          .removeClass('crm-template-widget__input_error');
      }
    });

    return errors_count === 0;
  }

  return function (params) {
    var self = this;

    return getTemplate('users')
      .then(function (template) {
        params.$el.append(template.render({
          roles: [
            {
              code: 'manager',
              title: self.i18n('users').role_manager,
              description: self.i18n('users').role_manager_description
            },
            {
              code: 'manager_account',
              title: self.i18n('users').role_manager_account,
              description: self.i18n('users').role_manager_account_description
            },
            {
              code: 'manager_call',
              title: self.i18n('users').role_manager_call,
              description: self.i18n('users').role_manager_call_description
            }
          ],
          values: params.data,
          langs: {
            placeholder: self.i18n('users').email_placeholder,
            submit: self.i18n('next_step')
          }
        }));

        // клик по кнопке отправки формы
        // перед отправкой провалидируем форму,
        // чтобы хотя бы одно поле в каждом
        // блоке было заполнено
        params.$el.on('click', '.js-wizard-users-submit', function (e) {
          e.preventDefault();

          if (validateForm(params.$el.find('form'))) {
            params.submit();
          }
        });
      });
  };
});